@@ -123,6 +123,8 @@ double Slic::get_vals_dist(vector<double>& values1, vector<double>& values2,
     return jensen_shannon(values1, values2);
   } else if (type == "dtw"){
     return dtw3(values1, values2);
+  } else if (type == "dtw2d"){
+    return dtw2d(values1, values2);
   } else if (type != ""){
     return custom_distance(values1, values2, type);
   } else {
@@ -361,7 +363,7 @@ void Slic::generate_superpixels(integers mat, doubles_matrix<> vals, double step
 void Slic::create_connectivity(doubles_matrix<> vals, cpp11::function avg_fun_fun, std::string& avg_fun_name, int lims, int verbose) {
   if (verbose > 0) Rprintf("Cleaning connectivity: ");
   int label = 0;
-  int adjlabel = 0;
+  int adjlabel = -1;
   const int dx4[4] = {-1,  0,  1,  0};
   const int dy4[4] = { 0, -1,  0,  1};
 
@@ -370,7 +372,7 @@ void Slic::create_connectivity(doubles_matrix<> vals, cpp11::function avg_fun_fu
     lims = lims >> 2;
   }
 
-    for (int i = 0; i < mat_dims[1]; i++) {
+  for (int i = 0; i < mat_dims[1]; i++) {
     vector<int> ncl; ncl.reserve(mat_dims[0]);
     for (int j = 0; j < mat_dims[0]; j++) {
       ncl.push_back(-1);
@@ -399,6 +401,8 @@ void Slic::create_connectivity(doubles_matrix<> vals, cpp11::function avg_fun_fu
           if (x >= 0 && x < mat_dims[1] && y >= 0 && y < mat_dims[0]) {
             if (new_clusters[x][y] >= 0) {
               adjlabel = new_clusters[x][y];
+            // } else {
+            //   adjlabel = -1;
             }
           }
         }
@@ -416,7 +420,10 @@ void Slic::create_connectivity(doubles_matrix<> vals, cpp11::function avg_fun_fu
 
                 elements.push_back(element2);
                 new_clusters[x][y] = label;
+                // Rprintf("j:%u", label);
                 count += 1;
+                // Rprintf("j:%u", count);
+
               }
             }
           }
@@ -427,10 +434,12 @@ void Slic::create_connectivity(doubles_matrix<> vals, cpp11::function avg_fun_fu
         if (count <= lims) {
           for (int c = 0; c < count; c++) {
             new_clusters[elements[c][1]][elements[c][0]] = adjlabel;
+            // Rprintf("j:%u", adjlabel);
           }
           label = label - 1;
         }
         label = label + 1;
+        adjlabel = -1;
       }
     }
   }
